@@ -21,7 +21,7 @@ Usage::
     list_hsms_paginator: ListHsmsPaginator = client.get_paginator("list_hsms")
     list_luna_clients_paginator: ListLunaClientsPaginator = client.get_paginator("list_luna_clients")
 """
-from mypy_boto3_cloudhsm.client import CloudHSMClient, CloudHSMClient as Client
+from mypy_boto3_cloudhsm.client import CloudHSMClient as Client, CloudHSMClient
 from mypy_boto3_cloudhsm.paginator import (
     ListHapgsPaginator,
     ListHsmsPaginator,
